@@ -22,10 +22,11 @@ class Actor:
     _till: Union[int, float, Callable, None]
     _active: bool
     _after: List[Actor]
+    _followers: List[Actor]
+    _label: Optional[str]
 
     _time: Union[int, float]
     _status: List[str]
-    _followers: List[Actor]
 
     def __init__(
         self,
@@ -37,6 +38,7 @@ class Actor:
         till: Optional[int | float | Callable] = None,
         active: bool = True,
         after: Optional[Actor | List[Actor]] = None,
+        label: Optional[str] = None,
     ) -> None:
 
         # generate a unique id for this actor
@@ -107,6 +109,9 @@ class Actor:
         if after is not None:
             self.status.append("onhold")
 
+        # assign the label to this actor
+        self._label = label or str()
+
         # schedule the actor onto timeline
         if self.onhold is False and self.active is True:
             self.timeline.schedule(self)
@@ -231,7 +236,7 @@ class Actor:
         else:
             return resource.release(self, amount)
 
-    def consume(self, producer: Producer, amount: Optional[int] = None) -> bool:
+    def consume(self, producer: Producer, amount: int = 1) -> bool:
         return producer.distribute(self, amount)
 
     @property
